@@ -6,7 +6,7 @@ require 5.005_62; use strict; use warnings;
 
 Class::Maker::class
 {
-	attribute =>
+	public =>
 	{
 		string => [qw/creation expiration/],
 	}
