@@ -4,11 +4,12 @@ our $VERSION = '0.002';
 
 package Trustee;
 
-use Data::Verify qw( verify assess );
+use Data::Type qw(:all);
+use Error qw(:try);
 
 Class::Maker::class
 {
-	attribute =>
+	public =>
 	{
 		string => [qw( field type id tiewith )],
 
